@@ -4,17 +4,20 @@ from rest_framework.response import Response
 
 from .models import Category
 from .serializers import CategorySerializer
+from rest_framework.filters import OrderingFilter
+from .filter import CategoryFilter
+from rest_framework import filters
+from django_filters.rest_framework.backends import DjangoFilterBackend
 
 
 class CategoryView(CustomModelViewSet, TreeAPIView):
     model_class = Category
     serializer_class = CategorySerializer
     pagination_class = None
-
-    filterset_fields = {
-        'title': ['contains'],
-        'category_type': ['exact'],
-    }
+    filterset_class = CategoryFilter
+    filter_backends = [
+        DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter]
+    ordering_fields = '__all__'
 
     @action(detail=False, methods=['post'], url_path='sort', url_name='sort')
     def sort(self, request, *args, **kwargs):
