@@ -12,12 +12,15 @@ EventChatView = import_string('EVENT.chat.views')
 EventConfigurationView = import_string('EVENT.configuration.views')
 EventCommentView = import_string('EVENT.comment.views')
 EventVoteView = import_string('EVENT.vote.views')
+EventVoteUserView = import_string('EVENT.vote.user_views')
 EventVenueView = import_string('EVENT.venue.views')
 
 
 router = DefaultRouter(trailing_slash=False)
 router.register(r'event/venue', EventVenueView,
                 basename='event-venue')
+router.register(r'event/vote/user', EventVoteUserView,
+                basename='event-vote-user')
 router.register(r'event/vote', EventVoteView,
                 basename='event-vote')
 router.register(r'event/configuration', EventConfigurationView,
