@@ -4,6 +4,10 @@ from rest_framework import status
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
 from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler, jwt_get_openid_handler
+from .filter import EventVoteFilter
+from rest_framework import filters
+from django_filters.rest_framework.backends import DjangoFilterBackend
+
 
 EventVote = import_string('EVENT.vote.models')
 EventVoteSerializer = import_string('EVENT.vote.serializers')
@@ -16,12 +20,10 @@ class EventVoteView(CustomModelViewSet):
     serializer_class = EventVoteSerializer
     pagination_class = None
 
-    filterset_fields = {
-        'title': ['contains'],
-        'event_id': ['exact'],
-        'schedule_id': ['exact'],
-
-    }
+    filterset_class = EventVoteFilter
+    filter_backends = [
+        DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter]
+    ordering_fields = '__all__'
 
     def create(self, request, *args, **kwargs):
         event_id = self.request.data.get('event_id', None)
