@@ -15,11 +15,6 @@ class UserView(CustomModelViewSet, FrontendView):
     model_class = User
     serializer_class = UserSerializer
 
-    filterset_fields = {
-        'wechat_profile__nick_name': ['contains'],
-        'level': ['exact'],
-    }
-
     def create(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
