@@ -1,18 +1,16 @@
 import time
 import random
 import string
-from urllib import parse
 from django.conf import settings
 from django.http import HttpResponse, HttpResponseRedirect
 from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from rest_framework.response import Response
-from wechatpy import parse_message, create_reply, utils
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat
-from bluedot_rest_framework.utils.func import orm_bulk_update
 
 from . import MiniProgram, OfficialAccount, WXBizDataCrypt, official_account_oauth
+from .utils import create_auth_token
 from .models import WeChatUser
 User = import_string('USER.models')
 
@@ -30,7 +28,7 @@ class JSSdk(APIView):
         signature = OfficialAccount.jsapi.get_jsapi_signature(
             nonceStr, ticket, timestamp, referer)
         return Response({
-            'appId': settings.WECHAT['OFFIACCOUNT']['APPID'],
+            'appId': settings.BLUEDOT_REST_FRAMEWORK['WECHAT']['OFFIACCOUNT']['APPID'],
             'timestamp': timestamp,
             'nonceStr': nonceStr,
             'signature': signature,
@@ -87,49 +85,18 @@ class OAuth(APIView):
     permission_classes = ()
 
     def get(self, request, *args, **kwargs):
-        redirect_uri = "http://" + request.get_host() + request.get_full_path()
         code = request.query_params.get('code', None)
-        # referer_uri = request.query_params.get('referer_uri', None)
-
+        referer_uri = request.META['HTTP_REFERER']
         if code:
             wechat_oauth = official_account_oauth(
-                redirect_uri, 'snsapi_userinfo')
+                referer_uri, 'snsapi_userinfo')
             wechat_oauth.fetch_access_token(code)
             user_info = wechat_oauth.get_user_info()
-
-            user_data = {
-                'unionid': user_info.get('unionid', ''),
-                'openid': user_info.get('openid', ''),
-                'nick_name': user_info.get('nickname', ''),
-                'avatar_url': user_info.get('headimgurl', ''),
-                'gender': user_info.get('sex', ''),
-                'province': user_info.get('province', ''),
-                'city': user_info.get('city', ''),
-                'country': user_info.get('country', ''),
-                'language': user_info.get('language', '')
-            }
-
-            wechat_queryset = WeChatUser.objects.filter(
-                openid=user_info['openid']).first()
-            if wechat_queryset:
-                orm_bulk_update(wechat_queryset, user_data)
-            else:
-                wechat_queryset = WeChatUser.objects.create(**user_data)
-            user_id = 0
-            user_queryset = User.objects.filter(
-                wechat_id=wechat_queryset.pk).first()
-            if user_queryset:
-                user_id = user_queryset.pk
-            token = jwt_create_token_wechat(
-                openid=wechat_queryset.openid, unionid=wechat_queryset.unionid, userid=user_id, wechat_id=wechat_queryset.pk)
+            token = create_auth_token(user_info)
             return Response({'token': token})
         else:
-            referer_uri = parse.quote(request.META['HTTP_REFERER'])
-            link_type = '?'
-            if "?" in referer_uri:
-                link_type = '&'
             wechat_oauth = official_account_oauth(
-                redirect_uri + link_type + 'referer_uri=' + referer_uri, 'snsapi_userinfo')
+                referer_uri, 'snsapi_userinfo')
             url = wechat_oauth.authorize_url
             return HttpResponseRedirect(url)
 
